/* SPDX-License-Identifier: LGPL-2.1-or-later */

#include "bus-util.h"
#include "bus-polkit.h"
#include "bus-log-control-api.h"
#include "webos-manager.h"
#include "webos-manager-bus.h"

static int webos_manager_connect_bus(Manager *m) {
    int r;

    r = bus_open_system_watch_bind_with_description(&m->bus, "bus-api-webos");
    if (r < 0)
        return log_error_errno(r, "Failed to connect to bus: %m");

    r = bus_add_implementation(m->bus, &webos_manager_object, m);
    if (r < 0)
        return r;

    r = bus_log_control_api_register(m->bus);
    if (r < 0)
        return r;

    r = sd_bus_request_name_async(m->bus, NULL, "com.webos.MemoryManager1", 0, NULL, NULL);
    if (r < 0)
        return log_error_errno(r, "Failed to request name: %m");

    r = sd_bus_attach_event(m->bus, m->event, 0);
    if (r < 0)
        return log_error_errno(r, "Failed to attach bus to event loop: %m");

    return 0;
}

int webos_manager_start(Manager *m) {
    int r;

    assert(m);

    r = webos_manager_connect_bus(m);
    if (r < 0)
        return r;

    return 0;
}
